@@ -40,7 +40,9 @@ WITH_TIMESTAMP=
 WITH_COMMIT_ID=
 DIST=
 
-WITHOUT_JAVADOC=
+WITH_JAVA=true
+WITH_NATIVE=true
+WITH_JAVADOC=true
 WITH_TESTS=
 
 VERBOSE=
@@ -68,6 +70,8 @@ usage() {
     echo "    --with-timestamp       Append timestamp to release number."
     echo "    --with-commit-id       Append commit ID to release number."
     echo "    --dist=<name>          Distribution name (e.g. fc28)."
+    echo "    --without-java         Do not build Java binaries."
+    echo "    --without-native       Do not build native binaries."
     echo "    --without-javadoc      Do not build Javadoc package."
     echo "    --with-tests           Run unit tests."
     echo " -v,--verbose              Run in verbose mode."
@@ -176,7 +180,7 @@ generate_rpm_spec() {
     fi
 
     # hard-code Javadoc option
-    if [ "$WITHOUT_JAVADOC" = true ] ; then
+    if [ "$WITH_JAVADOC" = false ] ; then
         # convert bcond_without into bcond_with such that Javadoc package is not built by default
         sed -i "s/%\(bcond_without *javadoc\)\$/# \1\n%bcond_with javadoc/g" "$SPEC_FILE"
     fi
@@ -253,8 +257,14 @@ while getopts v-: arg ; do
         dist=?*)
             DIST="$LONG_OPTARG"
             ;;
+        without-java)
+            WITH_JAVA=false
+            ;;
+        without-native)
+            WITH_NATIVE=false
+            ;;
         without-javadoc)
-            WITHOUT_JAVADOC=true
+            WITH_JAVADOC=false
             ;;
         with-tests)
             WITH_TESTS=true
@@ -382,7 +392,15 @@ if [ "$BUILD_TARGET" = "dist" ] ; then
 
     OPTIONS+=(-DVERSION="$VERSION")
 
-    if [ "$WITHOUT_JAVADOC" = true ] ; then
+    if [ "$WITH_JAVA" = false ] ; then
+        OPTIONS+=(-DWITH_JAVA=FALSE)
+    fi
+
+    if [ "$WITH_NATIVE" = false ] ; then
+        OPTIONS+=(-DWITH_NATIVE=FALSE)
+    fi
+
+    if [ "$WITH_JAVADOC" = false ] ; then
         OPTIONS+=(-DWITH_JAVADOC=FALSE)
     fi
 
@@ -397,9 +415,15 @@ if [ "$BUILD_TARGET" = "dist" ] ; then
     OPTIONS+=(CMAKE_NO_VERBOSE=1)
     OPTIONS+=(--no-print-directory)
 
-    make "${OPTIONS[@]}" all
+    if [ "$WITH_JAVA" = true ] ; then
+        make "${OPTIONS[@]}" java
+    fi
 
-    if [ "$WITHOUT_JAVADOC" != true ] ; then
+    if [ "$WITH_NATIVE" = true ] ; then
+        make "${OPTIONS[@]}" native
+    fi
+
+    if [ "$WITH_JAVADOC" = true ] ; then
         make "${OPTIONS[@]}" javadoc
     fi
 
@@ -409,13 +433,23 @@ if [ "$BUILD_TARGET" = "dist" ] ; then
 
     echo
     echo "Build artifacts:"
-    echo "- Java archives:"
-    echo "    $WORK_DIR/jss.jar"
-    echo "    $WORK_DIR/symkey/jss-symkey.jar"
-    echo "- shared libraries:"
-    echo "    $WORK_DIR/libjss.so"
-    echo "    $WORK_DIR/symkey/libjss-symkey.so"
-    echo "- documentation: $WORK_DIR/docs"
+
+    if [ "$WITH_JAVA" = true ] ; then
+        echo "- Java binaries:"
+        echo "    $WORK_DIR/jss.jar"
+    fi
+
+    if [ "$WITH_NATIVE" = true ] ; then
+        echo "- native binaries:"
+        echo "    $WORK_DIR/libjss.so"
+        echo "    $WORK_DIR/symkey/libjss-symkey.so"
+    fi
+
+    if [ "$WITH_JAVADOC" = true ] ; then
+        echo "- documentation:"
+        echo "    $WORK_DIR/docs"
+    fi
+
     echo
     echo "To run the tests: $0 --with-tests"
     echo "To install the build: $0 install"
